# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_GENERATE_INFLATED_METADATA = Metadata(
    id="27b14fd47a41d6ad62e63cedcf7c0e24652ecc90.boutiques",
    name="surface-generate-inflated",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceGenerateInflatedParameters = typing.TypedDict('SurfaceGenerateInflatedParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-generate-inflated"]],
    "anatomical_surface_in": InputPathType,
    "inflated_surface_out": str,
    "very_inflated_surface_out": str,
    "opt_iterations_scale_iterations_scale_value": typing.NotRequired[float | None],
})
SurfaceGenerateInflatedParametersTagged = typing.TypedDict('SurfaceGenerateInflatedParametersTagged', {
    "@type": typing.Literal["workbench/surface-generate-inflated"],
    "anatomical_surface_in": InputPathType,
    "inflated_surface_out": str,
    "very_inflated_surface_out": str,
    "opt_iterations_scale_iterations_scale_value": typing.NotRequired[float | None],
})


class SurfaceGenerateInflatedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceGenerateInflatedParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inflated_surface_out: OutputPathType
    """the output inflated surface"""
    very_inflated_surface_out: OutputPathType
    """the output very inflated surface"""


def surface_generate_inflated_params(
    anatomical_surface_in: InputPathType,
    inflated_surface_out: str,
    very_inflated_surface_out: str,
    opt_iterations_scale_iterations_scale_value: float | None = None,
) -> SurfaceGenerateInflatedParametersTagged:
    """
    Build parameters.
    
    Args:
        anatomical_surface_in: the anatomical surface.
        inflated_surface_out: the output inflated surface.
        very_inflated_surface_out: the output very inflated surface.
        opt_iterations_scale_iterations_scale_value: optional iterations\
            scaling: iterations-scale value.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-generate-inflated",
        "anatomical_surface_in": anatomical_surface_in,
        "inflated_surface_out": inflated_surface_out,
        "very_inflated_surface_out": very_inflated_surface_out,
    }
    if opt_iterations_scale_iterations_scale_value is not None:
        params["opt_iterations_scale_iterations_scale_value"] = opt_iterations_scale_iterations_scale_value
    return params


def surface_generate_inflated_cargs(
    params: SurfaceGenerateInflatedParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-generate-inflated")
    cargs.append(execution.input_file(params.get("anatomical_surface_in", None)))
    cargs.append(params.get("inflated_surface_out", None))
    cargs.append(params.get("very_inflated_surface_out", None))
    if params.get("opt_iterations_scale_iterations_scale_value", None) is not None:
        cargs.extend([
            "-iterations-scale",
            str(params.get("opt_iterations_scale_iterations_scale_value", None))
        ])
    return cargs


def surface_generate_inflated_outputs(
    params: SurfaceGenerateInflatedParameters,
    execution: Execution,
) -> SurfaceGenerateInflatedOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceGenerateInflatedOutputs(
        root=execution.output_file("."),
        inflated_surface_out=execution.output_file(params.get("inflated_surface_out", None)),
        very_inflated_surface_out=execution.output_file(params.get("very_inflated_surface_out", None)),
    )
    return ret


def surface_generate_inflated_execute(
    params: SurfaceGenerateInflatedParameters,
    runner: Runner | None = None,
) -> SurfaceGenerateInflatedOutputs:
    """
    surface-generate-inflated
    
    Surface generate inflated.
    
    Generate inflated and very inflated surfaces. The output surfaces are
    'matched' (have same XYZ range) to the anatomical surface. In most cases, an
    iterations-scale of 1.0 (default) is sufficient. However, if the surface
    contains a large number of vertices (150,000), try an iterations-scale of
    2.5.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGenerateInflatedOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_GENERATE_INFLATED_METADATA)
    params = execution.params(params)
    cargs = surface_generate_inflated_cargs(params, execution)
    ret = surface_generate_inflated_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_generate_inflated(
    anatomical_surface_in: InputPathType,
    inflated_surface_out: str,
    very_inflated_surface_out: str,
    opt_iterations_scale_iterations_scale_value: float | None = None,
    runner: Runner | None = None,
) -> SurfaceGenerateInflatedOutputs:
    """
    surface-generate-inflated
    
    Surface generate inflated.
    
    Generate inflated and very inflated surfaces. The output surfaces are
    'matched' (have same XYZ range) to the anatomical surface. In most cases, an
    iterations-scale of 1.0 (default) is sufficient. However, if the surface
    contains a large number of vertices (150,000), try an iterations-scale of
    2.5.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        anatomical_surface_in: the anatomical surface.
        inflated_surface_out: the output inflated surface.
        very_inflated_surface_out: the output very inflated surface.
        opt_iterations_scale_iterations_scale_value: optional iterations\
            scaling: iterations-scale value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGenerateInflatedOutputs`).
    """
    params = surface_generate_inflated_params(
        anatomical_surface_in=anatomical_surface_in,
        inflated_surface_out=inflated_surface_out,
        very_inflated_surface_out=very_inflated_surface_out,
        opt_iterations_scale_iterations_scale_value=opt_iterations_scale_iterations_scale_value,
    )
    return surface_generate_inflated_execute(params, runner)


__all__ = [
    "SURFACE_GENERATE_INFLATED_METADATA",
    "SurfaceGenerateInflatedOutputs",
    "surface_generate_inflated",
    "surface_generate_inflated_execute",
    "surface_generate_inflated_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

GIFTI_LABEL_ADD_PREFIX_METADATA = Metadata(
    id="b2a8a58ea9018d7169641e6e86ac24e4e6afcab8.boutiques",
    name="gifti-label-add-prefix",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


GiftiLabelAddPrefixParameters = typing.TypedDict('GiftiLabelAddPrefixParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/gifti-label-add-prefix"]],
    "label_in": InputPathType,
    "prefix": str,
    "label_out": str,
})
GiftiLabelAddPrefixParametersTagged = typing.TypedDict('GiftiLabelAddPrefixParametersTagged', {
    "@type": typing.Literal["workbench/gifti-label-add-prefix"],
    "label_in": InputPathType,
    "prefix": str,
    "label_out": str,
})


class GiftiLabelAddPrefixOutputs(typing.NamedTuple):
    """
    Output object returned when calling `GiftiLabelAddPrefixParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""


def gifti_label_add_prefix_params(
    label_in: InputPathType,
    prefix: str,
    label_out: str,
) -> GiftiLabelAddPrefixParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input label file.
        prefix: the prefix string to add.
        label_out: the output label file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/gifti-label-add-prefix",
        "label_in": label_in,
        "prefix": prefix,
        "label_out": label_out,
    }
    return params


def gifti_label_add_prefix_cargs(
    params: GiftiLabelAddPrefixParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-gifti-label-add-prefix")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("prefix", None))
    cargs.append(params.get("label_out", None))
    return cargs


def gifti_label_add_prefix_outputs(
    params: GiftiLabelAddPrefixParameters,
    execution: Execution,
) -> GiftiLabelAddPrefixOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = GiftiLabelAddPrefixOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(params.get("label_out", None)),
    )
    return ret


def gifti_label_add_prefix_execute(
    params: GiftiLabelAddPrefixParameters,
    runner: Runner | None = None,
) -> GiftiLabelAddPrefixOutputs:
    """
    gifti-label-add-prefix
    
    Add prefix to all label names in a gifti label file.
    
    For each label other than '???', prepend <prefix> to the label name.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiLabelAddPrefixOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_LABEL_ADD_PREFIX_METADATA)
    params = execution.params(params)
    cargs = gifti_label_add_prefix_cargs(params, execution)
    ret = gifti_label_add_prefix_outputs(params, execution)
    execution.run(cargs)
    return ret


def gifti_label_add_prefix(
    label_in: InputPathType,
    prefix: str,
    label_out: str,
    runner: Runner | None = None,
) -> GiftiLabelAddPrefixOutputs:
    """
    gifti-label-add-prefix
    
    Add prefix to all label names in a gifti label file.
    
    For each label other than '???', prepend <prefix> to the label name.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input label file.
        prefix: the prefix string to add.
        label_out: the output label file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiLabelAddPrefixOutputs`).
    """
    params = gifti_label_add_prefix_params(
        label_in=label_in,
        prefix=prefix,
        label_out=label_out,
    )
    return gifti_label_add_prefix_execute(params, runner)


__all__ = [
    "GIFTI_LABEL_ADD_PREFIX_METADATA",
    "GiftiLabelAddPrefixOutputs",
    "gifti_label_add_prefix",
    "gifti_label_add_prefix_execute",
    "gifti_label_add_prefix_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

LABEL_ERODE_METADATA = Metadata(
    id="99712b5dfa61e349e4c3839ddd13dfb8b7032631.boutiques",
    name="label-erode",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


LabelErodeParameters = typing.TypedDict('LabelErodeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/label-erode"]],
    "label": InputPathType,
    "surface": InputPathType,
    "erode_dist": float,
    "label_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
LabelErodeParametersTagged = typing.TypedDict('LabelErodeParametersTagged', {
    "@type": typing.Literal["workbench/label-erode"],
    "label": InputPathType,
    "surface": InputPathType,
    "erode_dist": float,
    "label_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


class LabelErodeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `LabelErodeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""


def label_erode_params(
    label: InputPathType,
    surface: InputPathType,
    erode_dist: float,
    label_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
) -> LabelErodeParametersTagged:
    """
    Build parameters.
    
    Args:
        label: the input label.
        surface: the surface to erode on.
        erode_dist: distance in mm to erode the labels.
        label_out: the output label file.
        opt_roi_roi_metric: assume values outside this roi are labeled: metric\
            file, positive values denote vertices that have data.
        opt_column_column: select a single column to erode: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/label-erode",
        "label": label,
        "surface": surface,
        "erode_dist": erode_dist,
        "label_out": label_out,
    }
    if opt_roi_roi_metric is not None:
        params["opt_roi_roi_metric"] = opt_roi_roi_metric
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def label_erode_cargs(
    params: LabelErodeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-erode")
    cargs.append(execution.input_file(params.get("label", None)))
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(str(params.get("erode_dist", None)))
    cargs.append(params.get("label_out", None))
    if params.get("opt_roi_roi_metric", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_metric", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    return cargs


def label_erode_outputs(
    params: LabelErodeParameters,
    execution: Execution,
) -> LabelErodeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = LabelErodeOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(params.get("label_out", None)),
    )
    return ret


def label_erode_execute(
    params: LabelErodeParameters,
    runner: Runner | None = None,
) -> LabelErodeOutputs:
    """
    label-erode
    
    Erode a label file.
    
    Around each vertex that is unlabeled, set surrounding vertices to unlabeled.
    The surrounding vertices are all immediate neighbors and all vertices within
    the specified distance.
    
    Note that the -corrected-areas option uses an approximate correction for
    distance along the surface.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelErodeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_ERODE_METADATA)
    params = execution.params(params)
    cargs = label_erode_cargs(params, execution)
    ret = label_erode_outputs(params, execution)
    execution.run(cargs)
    return ret


def label_erode(
    label: InputPathType,
    surface: InputPathType,
    erode_dist: float,
    label_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> LabelErodeOutputs:
    """
    label-erode
    
    Erode a label file.
    
    Around each vertex that is unlabeled, set surrounding vertices to unlabeled.
    The surrounding vertices are all immediate neighbors and all vertices within
    the specified distance.
    
    Note that the -corrected-areas option uses an approximate correction for
    distance along the surface.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label: the input label.
        surface: the surface to erode on.
        erode_dist: distance in mm to erode the labels.
        label_out: the output label file.
        opt_roi_roi_metric: assume values outside this roi are labeled: metric\
            file, positive values denote vertices that have data.
        opt_column_column: select a single column to erode: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelErodeOutputs`).
    """
    params = label_erode_params(
        label=label,
        surface=surface,
        erode_dist=erode_dist,
        label_out=label_out,
        opt_roi_roi_metric=opt_roi_roi_metric,
        opt_column_column=opt_column_column,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
    )
    return label_erode_execute(params, runner)


__all__ = [
    "LABEL_ERODE_METADATA",
    "LabelErodeOutputs",
    "label_erode",
    "label_erode_execute",
    "label_erode_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_FIND_CLUSTERS_METADATA = Metadata(
    id="bad1c1bcb6a58fa1b8a2f5e514a762cf71edc56a.boutiques",
    name="metric-find-clusters",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricFindClustersParameters = typing.TypedDict('MetricFindClustersParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-find-clusters"]],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "value_threshold": float,
    "minimum_area": float,
    "metric_out": str,
    "opt_less_than": bool,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_size_ratio_ratio": typing.NotRequired[float | None],
    "opt_distance_distance": typing.NotRequired[float | None],
    "opt_start_startval": typing.NotRequired[int | None],
})
MetricFindClustersParametersTagged = typing.TypedDict('MetricFindClustersParametersTagged', {
    "@type": typing.Literal["workbench/metric-find-clusters"],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "value_threshold": float,
    "minimum_area": float,
    "metric_out": str,
    "opt_less_than": bool,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_size_ratio_ratio": typing.NotRequired[float | None],
    "opt_distance_distance": typing.NotRequired[float | None],
    "opt_start_startval": typing.NotRequired[int | None],
})


class MetricFindClustersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricFindClustersParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_find_clusters_params(
    surface: InputPathType,
    metric_in: InputPathType,
    value_threshold: float,
    minimum_area: float,
    metric_out: str,
    opt_less_than: bool = False,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_size_ratio_ratio: float | None = None,
    opt_distance_distance: float | None = None,
    opt_start_startval: int | None = None,
) -> MetricFindClustersParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to compute on.
        metric_in: the input metric.
        value_threshold: threshold for data values.
        minimum_area: threshold for cluster area, in mm^2.
        metric_out: the output metric.
        opt_less_than: find values less than <value-threshold>, rather than\
            greater.
        opt_roi_roi_metric: select a region of interest: the roi, as a metric.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_column_column: select a single column: the column number or name.
        opt_size_ratio_ratio: ignore clusters smaller than a given fraction of\
            the largest cluster in map: fraction of the largest cluster's area.
        opt_distance_distance: ignore clusters further than a given distance\
            from the largest cluster: how far from the largest cluster a cluster\
            can be, edge to edge, in mm.
        opt_start_startval: start labeling clusters from a value other than 1:\
            the value to give the first cluster found.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-find-clusters",
        "surface": surface,
        "metric_in": metric_in,
        "value_threshold": value_threshold,
        "minimum_area": minimum_area,
        "metric_out": metric_out,
        "opt_less_than": opt_less_than,
    }
    if opt_roi_roi_metric is not None:
        params["opt_roi_roi_metric"] = opt_roi_roi_metric
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if opt_size_ratio_ratio is not None:
        params["opt_size_ratio_ratio"] = opt_size_ratio_ratio
    if opt_distance_distance is not None:
        params["opt_distance_distance"] = opt_distance_distance
    if opt_start_startval is not None:
        params["opt_start_startval"] = opt_start_startval
    return params


def metric_find_clusters_cargs(
    params: MetricFindClustersParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-find-clusters")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(str(params.get("value_threshold", None)))
    cargs.append(str(params.get("minimum_area", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_less_than", False):
        cargs.append("-less-than")
    if params.get("opt_roi_roi_metric", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_metric", None))
        ])
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("opt_size_ratio_ratio", None) is not None:
        cargs.extend([
            "-size-ratio",
            str(params.get("opt_size_ratio_ratio", None))
        ])
    if params.get("opt_distance_distance", None) is not None:
        cargs.extend([
            "-distance",
            str(params.get("opt_distance_distance", None))
        ])
    if params.get("opt_start_startval", None) is not None:
        cargs.extend([
            "-start",
            str(params.get("opt_start_startval", None))
        ])
    return cargs


def metric_find_clusters_outputs(
    params: MetricFindClustersParameters,
    execution: Execution,
) -> MetricFindClustersOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricFindClustersOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_find_clusters_execute(
    params: MetricFindClustersParameters,
    runner: Runner | None = None,
) -> MetricFindClustersOutputs:
    """
    metric-find-clusters
    
    Filter clusters by surface area.
    
    Outputs a metric with nonzero integers for all vertices within a large
    enough cluster, and zeros elsewhere. The integers denote cluster membership
    (by default, first cluster found will use value 1, second cluster 2, etc).
    Cluster values are not reused across maps of the output, but instead keep
    counting up. By default, values greater than <value-threshold> are
    considered to be in a cluster, use -less-than to test for values less than
    the threshold. To apply this as a mask to the data, or to do more
    complicated thresholding, see -metric-math.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricFindClustersOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_FIND_CLUSTERS_METADATA)
    params = execution.params(params)
    cargs = metric_find_clusters_cargs(params, execution)
    ret = metric_find_clusters_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_find_clusters(
    surface: InputPathType,
    metric_in: InputPathType,
    value_threshold: float,
    minimum_area: float,
    metric_out: str,
    opt_less_than: bool = False,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_size_ratio_ratio: float | None = None,
    opt_distance_distance: float | None = None,
    opt_start_startval: int | None = None,
    runner: Runner | None = None,
) -> MetricFindClustersOutputs:
    """
    metric-find-clusters
    
    Filter clusters by surface area.
    
    Outputs a metric with nonzero integers for all vertices within a large
    enough cluster, and zeros elsewhere. The integers denote cluster membership
    (by default, first cluster found will use value 1, second cluster 2, etc).
    Cluster values are not reused across maps of the output, but instead keep
    counting up. By default, values greater than <value-threshold> are
    considered to be in a cluster, use -less-than to test for values less than
    the threshold. To apply this as a mask to the data, or to do more
    complicated thresholding, see -metric-math.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to compute on.
        metric_in: the input metric.
        value_threshold: threshold for data values.
        minimum_area: threshold for cluster area, in mm^2.
        metric_out: the output metric.
        opt_less_than: find values less than <value-threshold>, rather than\
            greater.
        opt_roi_roi_metric: select a region of interest: the roi, as a metric.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_column_column: select a single column: the column number or name.
        opt_size_ratio_ratio: ignore clusters smaller than a given fraction of\
            the largest cluster in map: fraction of the largest cluster's area.
        opt_distance_distance: ignore clusters further than a given distance\
            from the largest cluster: how far from the largest cluster a cluster\
            can be, edge to edge, in mm.
        opt_start_startval: start labeling clusters from a value other than 1:\
            the value to give the first cluster found.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricFindClustersOutputs`).
    """
    params = metric_find_clusters_params(
        surface=surface,
        metric_in=metric_in,
        value_threshold=value_threshold,
        minimum_area=minimum_area,
        metric_out=metric_out,
        opt_less_than=opt_less_than,
        opt_roi_roi_metric=opt_roi_roi_metric,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
        opt_column_column=opt_column_column,
        opt_size_ratio_ratio=opt_size_ratio_ratio,
        opt_distance_distance=opt_distance_distance,
        opt_start_startval=opt_start_startval,
    )
    return metric_find_clusters_execute(params, runner)


__all__ = [
    "METRIC_FIND_CLUSTERS_METADATA",
    "MetricFindClustersOutputs",
    "metric_find_clusters",
    "metric_find_clusters_execute",
    "metric_find_clusters_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

WBSPARSE_MERGE_DENSE_METADATA = Metadata(
    id="678d6e48841edbd3b84295894b5e17d9b4f6d090.boutiques",
    name="wbsparse-merge-dense",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


WbsparseMergeDenseWbsparseParameters = typing.TypedDict('WbsparseMergeDenseWbsparseParameters', {
    "@type": typing.NotRequired[typing.Literal["wbsparse"]],
    "wbsparse_in": str,
})
WbsparseMergeDenseWbsparseParametersTagged = typing.TypedDict('WbsparseMergeDenseWbsparseParametersTagged', {
    "@type": typing.Literal["wbsparse"],
    "wbsparse_in": str,
})


WbsparseMergeDenseParameters = typing.TypedDict('WbsparseMergeDenseParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/wbsparse-merge-dense"]],
    "direction": str,
    "wbsparse_out": str,
    "wbsparse": typing.NotRequired[list[WbsparseMergeDenseWbsparseParameters] | None],
})
WbsparseMergeDenseParametersTagged = typing.TypedDict('WbsparseMergeDenseParametersTagged', {
    "@type": typing.Literal["workbench/wbsparse-merge-dense"],
    "direction": str,
    "wbsparse_out": str,
    "wbsparse": typing.NotRequired[list[WbsparseMergeDenseWbsparseParameters] | None],
})


def wbsparse_merge_dense_wbsparse_params(
    wbsparse_in: str,
) -> WbsparseMergeDenseWbsparseParametersTagged:
    """
    Build parameters.
    
    Args:
        wbsparse_in: a wbsparse file to merge.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "wbsparse",
        "wbsparse_in": wbsparse_in,
    }
    return params


def wbsparse_merge_dense_wbsparse_cargs(
    params: WbsparseMergeDenseWbsparseParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-wbsparse")
    cargs.append(params.get("wbsparse_in", None))
    return cargs


class WbsparseMergeDenseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `WbsparseMergeDenseParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def wbsparse_merge_dense_params(
    direction: str,
    wbsparse_out: str,
    wbsparse: list[WbsparseMergeDenseWbsparseParameters] | None = None,
) -> WbsparseMergeDenseParametersTagged:
    """
    Build parameters.
    
    Args:
        direction: which dimension to merge along, ROW or COLUMN.
        wbsparse_out: output - the output wbsparse file.
        wbsparse: specify an input wbsparse file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/wbsparse-merge-dense",
        "direction": direction,
        "wbsparse_out": wbsparse_out,
    }
    if wbsparse is not None:
        params["wbsparse"] = wbsparse
    return params


def wbsparse_merge_dense_cargs(
    params: WbsparseMergeDenseParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-wbsparse-merge-dense")
    cargs.append(params.get("direction", None))
    cargs.append(params.get("wbsparse_out", None))
    if params.get("wbsparse", None) is not None:
        cargs.extend([a for c in [wbsparse_merge_dense_wbsparse_cargs(s, execution) for s in params.get("wbsparse", None)] for a in c])
    return cargs


def wbsparse_merge_dense_outputs(
    params: WbsparseMergeDenseParameters,
    execution: Execution,
) -> WbsparseMergeDenseOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = WbsparseMergeDenseOutputs(
        root=execution.output_file("."),
    )
    return ret


def wbsparse_merge_dense_execute(
    params: WbsparseMergeDenseParameters,
    runner: Runner | None = None,
) -> WbsparseMergeDenseOutputs:
    """
    wbsparse-merge-dense
    
    Merge wbsparse files along dense dimension.
    
    The input wbsparse files must have matching mappings along the direction not
    specified, and the mapping along the specified direction must be brain
    models.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WbsparseMergeDenseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WBSPARSE_MERGE_DENSE_METADATA)
    params = execution.params(params)
    cargs = wbsparse_merge_dense_cargs(params, execution)
    ret = wbsparse_merge_dense_outputs(params, execution)
    execution.run(cargs)
    return ret


def wbsparse_merge_dense(
    direction: str,
    wbsparse_out: str,
    wbsparse: list[WbsparseMergeDenseWbsparseParameters] | None = None,
    runner: Runner | None = None,
) -> WbsparseMergeDenseOutputs:
    """
    wbsparse-merge-dense
    
    Merge wbsparse files along dense dimension.
    
    The input wbsparse files must have matching mappings along the direction not
    specified, and the mapping along the specified direction must be brain
    models.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        direction: which dimension to merge along, ROW or COLUMN.
        wbsparse_out: output - the output wbsparse file.
        wbsparse: specify an input wbsparse file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WbsparseMergeDenseOutputs`).
    """
    params = wbsparse_merge_dense_params(
        direction=direction,
        wbsparse_out=wbsparse_out,
        wbsparse=wbsparse,
    )
    return wbsparse_merge_dense_execute(params, runner)


__all__ = [
    "WBSPARSE_MERGE_DENSE_METADATA",
    "WbsparseMergeDenseOutputs",
    "wbsparse_merge_dense",
    "wbsparse_merge_dense_execute",
    "wbsparse_merge_dense_params",
    "wbsparse_merge_dense_wbsparse_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

BORDER_TO_ROIS_METADATA = Metadata(
    id="d27e55d16af9c127031efb25bfee0f3793658e98.boutiques",
    name="border-to-rois",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


BorderToRoisParameters = typing.TypedDict('BorderToRoisParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/border-to-rois"]],
    "surface": InputPathType,
    "border_file": InputPathType,
    "metric_out": str,
    "opt_border_name": typing.NotRequired[str | None],
    "opt_inverse": bool,
    "opt_include_border": bool,
})
BorderToRoisParametersTagged = typing.TypedDict('BorderToRoisParametersTagged', {
    "@type": typing.Literal["workbench/border-to-rois"],
    "surface": InputPathType,
    "border_file": InputPathType,
    "metric_out": str,
    "opt_border_name": typing.NotRequired[str | None],
    "opt_inverse": bool,
    "opt_include_border": bool,
})


class BorderToRoisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `BorderToRoisParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def border_to_rois_params(
    surface: InputPathType,
    border_file: InputPathType,
    metric_out: str,
    opt_border_name: str | None = None,
    opt_inverse: bool = False,
    opt_include_border: bool = False,
) -> BorderToRoisParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface the borders are drawn on.
        border_file: the border file.
        metric_out: the output metric file.
        opt_border_name: create ROI for only one border: the name of the border.
        opt_inverse: use inverse selection (outside border).
        opt_include_border: include vertices the border is closest to.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/border-to-rois",
        "surface": surface,
        "border_file": border_file,
        "metric_out": metric_out,
        "opt_inverse": opt_inverse,
        "opt_include_border": opt_include_border,
    }
    if opt_border_name is not None:
        params["opt_border_name"] = opt_border_name
    return params


def border_to_rois_cargs(
    params: BorderToRoisParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-to-rois")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("border_file", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_border_name", None) is not None:
        cargs.extend([
            "-border",
            params.get("opt_border_name", None)
        ])
    if params.get("opt_inverse", False):
        cargs.append("-inverse")
    if params.get("opt_include_border", False):
        cargs.append("-include-border")
    return cargs


def border_to_rois_outputs(
    params: BorderToRoisParameters,
    execution: Execution,
) -> BorderToRoisOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = BorderToRoisOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def border_to_rois_execute(
    params: BorderToRoisParameters,
    runner: Runner | None = None,
) -> BorderToRoisOutputs:
    """
    border-to-rois
    
    Make metric rois from borders.
    
    By default, draws ROIs inside all borders in the border file, as separate
    metric columns.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderToRoisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_TO_ROIS_METADATA)
    params = execution.params(params)
    cargs = border_to_rois_cargs(params, execution)
    ret = border_to_rois_outputs(params, execution)
    execution.run(cargs)
    return ret


def border_to_rois(
    surface: InputPathType,
    border_file: InputPathType,
    metric_out: str,
    opt_border_name: str | None = None,
    opt_inverse: bool = False,
    opt_include_border: bool = False,
    runner: Runner | None = None,
) -> BorderToRoisOutputs:
    """
    border-to-rois
    
    Make metric rois from borders.
    
    By default, draws ROIs inside all borders in the border file, as separate
    metric columns.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface the borders are drawn on.
        border_file: the border file.
        metric_out: the output metric file.
        opt_border_name: create ROI for only one border: the name of the border.
        opt_inverse: use inverse selection (outside border).
        opt_include_border: include vertices the border is closest to.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderToRoisOutputs`).
    """
    params = border_to_rois_params(
        surface=surface,
        border_file=border_file,
        metric_out=metric_out,
        opt_border_name=opt_border_name,
        opt_inverse=opt_inverse,
        opt_include_border=opt_include_border,
    )
    return border_to_rois_execute(params, runner)


__all__ = [
    "BORDER_TO_ROIS_METADATA",
    "BorderToRoisOutputs",
    "border_to_rois",
    "border_to_rois_execute",
    "border_to_rois_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_RESAMPLE_METADATA = Metadata(
    id="41e7032c2642e2cae7204e42a36f44dcbf767095.boutiques",
    name="surface-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceResampleAreaSurfsParameters = typing.TypedDict('SurfaceResampleAreaSurfsParameters', {
    "@type": typing.NotRequired[typing.Literal["area_surfs"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
SurfaceResampleAreaSurfsParametersTagged = typing.TypedDict('SurfaceResampleAreaSurfsParametersTagged', {
    "@type": typing.Literal["area_surfs"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


SurfaceResampleAreaMetricsParameters = typing.TypedDict('SurfaceResampleAreaMetricsParameters', {
    "@type": typing.NotRequired[typing.Literal["area_metrics"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
SurfaceResampleAreaMetricsParametersTagged = typing.TypedDict('SurfaceResampleAreaMetricsParametersTagged', {
    "@type": typing.Literal["area_metrics"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


SurfaceResampleParameters = typing.TypedDict('SurfaceResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-resample"]],
    "surface_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "method": str,
    "surface_out": str,
    "area_surfs": typing.NotRequired[SurfaceResampleAreaSurfsParameters | None],
    "area_metrics": typing.NotRequired[SurfaceResampleAreaMetricsParameters | None],
    "opt_bypass_sphere_check": bool,
})
SurfaceResampleParametersTagged = typing.TypedDict('SurfaceResampleParametersTagged', {
    "@type": typing.Literal["workbench/surface-resample"],
    "surface_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "method": str,
    "surface_out": str,
    "area_surfs": typing.NotRequired[SurfaceResampleAreaSurfsParameters | None],
    "area_metrics": typing.NotRequired[SurfaceResampleAreaMetricsParameters | None],
    "opt_bypass_sphere_check": bool,
})


def surface_resample_area_surfs_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> SurfaceResampleAreaSurfsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a relevant surface with <current-sphere> mesh.
        new_area: a relevant surface with <new-sphere> mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "area_surfs",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def surface_resample_area_surfs_cargs(
    params: SurfaceResampleAreaSurfsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-area-surfs")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def surface_resample_area_metrics_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> SurfaceResampleAreaMetricsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a metric file with vertex areas for <current-sphere> mesh.
        new_area: a metric file with vertex areas for <new-sphere> mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "area_metrics",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def surface_resample_area_metrics_cargs(
    params: SurfaceResampleAreaMetricsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-area-metrics")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


class SurfaceResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the output surface file"""


def surface_resample_params(
    surface_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    method: str,
    surface_out: str,
    area_surfs: SurfaceResampleAreaSurfsParameters | None = None,
    area_metrics: SurfaceResampleAreaMetricsParameters | None = None,
    opt_bypass_sphere_check: bool = False,
) -> SurfaceResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_in: the surface file to resample.
        current_sphere: a sphere surface with the mesh that the input surface\
            is currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        method: the method name.
        surface_out: the output surface file.
        area_surfs: specify surfaces to do vertex area correction based on.
        area_metrics: specify vertex area metrics to do area correction based\
            on.
        opt_bypass_sphere_check: ADVANCED: allow the current and new 'spheres'\
            to have arbitrary shape as long as they follow the same contour.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-resample",
        "surface_in": surface_in,
        "current_sphere": current_sphere,
        "new_sphere": new_sphere,
        "method": method,
        "surface_out": surface_out,
        "opt_bypass_sphere_check": opt_bypass_sphere_check,
    }
    if area_surfs is not None:
        params["area_surfs"] = area_surfs
    if area_metrics is not None:
        params["area_metrics"] = area_metrics
    return params


def surface_resample_cargs(
    params: SurfaceResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-resample")
    cargs.append(execution.input_file(params.get("surface_in", None)))
    cargs.append(execution.input_file(params.get("current_sphere", None)))
    cargs.append(execution.input_file(params.get("new_sphere", None)))
    cargs.append(params.get("method", None))
    cargs.append(params.get("surface_out", None))
    if params.get("area_surfs", None) is not None:
        cargs.extend(surface_resample_area_surfs_cargs(params.get("area_surfs", None), execution))
    if params.get("area_metrics", None) is not None:
        cargs.extend(surface_resample_area_metrics_cargs(params.get("area_metrics", None), execution))
    if params.get("opt_bypass_sphere_check", False):
        cargs.append("-bypass-sphere-check")
    return cargs


def surface_resample_outputs(
    params: SurfaceResampleParameters,
    execution: Execution,
) -> SurfaceResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceResampleOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(params.get("surface_out", None)),
    )
    return ret


def surface_resample_execute(
    params: SurfaceResampleParameters,
    runner: Runner | None = None,
) -> SurfaceResampleOutputs:
    """
    surface-resample
    
    Resample a surface to a different mesh.
    
    Resamples a surface file, given two spherical surfaces that are in register.
    If ADAP_BARY_AREA is used, exactly one of -area-surfs or -area-metrics must
    be specified. This method is not generally recommended for surface
    resampling, but is provided for completeness.
    
    The BARYCENTRIC method is generally recommended for anatomical surfaces, in
    order to minimize smoothing.
    
    For cut surfaces (including flatmaps), use -surface-cut-resample.
    
    Instead of resampling a spherical surface, the
    -surface-sphere-project-unproject command is recommended.
    
    The <method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = surface_resample_cargs(params, execution)
    ret = surface_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_resample(
    surface_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    method: str,
    surface_out: str,
    area_surfs: SurfaceResampleAreaSurfsParameters | None = None,
    area_metrics: SurfaceResampleAreaMetricsParameters | None = None,
    opt_bypass_sphere_check: bool = False,
    runner: Runner | None = None,
) -> SurfaceResampleOutputs:
    """
    surface-resample
    
    Resample a surface to a different mesh.
    
    Resamples a surface file, given two spherical surfaces that are in register.
    If ADAP_BARY_AREA is used, exactly one of -area-surfs or -area-metrics must
    be specified. This method is not generally recommended for surface
    resampling, but is provided for completeness.
    
    The BARYCENTRIC method is generally recommended for anatomical surfaces, in
    order to minimize smoothing.
    
    For cut surfaces (including flatmaps), use -surface-cut-resample.
    
    Instead of resampling a spherical surface, the
    -surface-sphere-project-unproject command is recommended.
    
    The <method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_in: the surface file to resample.
        current_sphere: a sphere surface with the mesh that the input surface\
            is currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        method: the method name.
        surface_out: the output surface file.
        area_surfs: specify surfaces to do vertex area correction based on.
        area_metrics: specify vertex area metrics to do area correction based\
            on.
        opt_bypass_sphere_check: ADVANCED: allow the current and new 'spheres'\
            to have arbitrary shape as long as they follow the same contour.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceResampleOutputs`).
    """
    params = surface_resample_params(
        surface_in=surface_in,
        current_sphere=current_sphere,
        new_sphere=new_sphere,
        method=method,
        surface_out=surface_out,
        area_surfs=area_surfs,
        area_metrics=area_metrics,
        opt_bypass_sphere_check=opt_bypass_sphere_check,
    )
    return surface_resample_execute(params, runner)


__all__ = [
    "SURFACE_RESAMPLE_METADATA",
    "SurfaceResampleOutputs",
    "surface_resample",
    "surface_resample_area_metrics_params",
    "surface_resample_area_surfs_params",
    "surface_resample_execute",
    "surface_resample_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_RESAMPLE_METADATA = Metadata(
    id="a6f5b36fba078762807c4f82e3c0374ec2f78287.boutiques",
    name="cifti-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiResampleWeightedParameters = typing.TypedDict('CiftiResampleWeightedParameters', {
    "@type": typing.NotRequired[typing.Literal["weighted"]],
    "opt_exponent_exponent": typing.NotRequired[float | None],
    "opt_legacy_cutoff": bool,
})
CiftiResampleWeightedParametersTagged = typing.TypedDict('CiftiResampleWeightedParametersTagged', {
    "@type": typing.Literal["weighted"],
    "opt_exponent_exponent": typing.NotRequired[float | None],
    "opt_legacy_cutoff": bool,
})


CiftiResampleVolumePredilateParameters = typing.TypedDict('CiftiResampleVolumePredilateParameters', {
    "@type": typing.NotRequired[typing.Literal["volume_predilate"]],
    "dilate_mm": float,
    "opt_nearest": bool,
    "weighted": typing.NotRequired[CiftiResampleWeightedParameters | None],
})
CiftiResampleVolumePredilateParametersTagged = typing.TypedDict('CiftiResampleVolumePredilateParametersTagged', {
    "@type": typing.Literal["volume_predilate"],
    "dilate_mm": float,
    "opt_nearest": bool,
    "weighted": typing.NotRequired[CiftiResampleWeightedParameters | None],
})


CiftiResampleWeighted1Parameters = typing.TypedDict('CiftiResampleWeighted1Parameters', {
    "@type": typing.NotRequired[typing.Literal["weighted_1"]],
    "opt_exponent_exponent": typing.NotRequired[float | None],
    "opt_legacy_cutoff": bool,
})
CiftiResampleWeighted1ParametersTagged = typing.TypedDict('CiftiResampleWeighted1ParametersTagged', {
    "@type": typing.Literal["weighted_1"],
    "opt_exponent_exponent": typing.NotRequired[float | None],
    "opt_legacy_cutoff": bool,
})


CiftiResampleSurfacePostdilateParameters = typing.TypedDict('CiftiResampleSurfacePostdilateParameters', {
    "@type": typing.NotRequired[typing.Literal["surface_postdilate"]],
    "dilate_mm": float,
    "opt_nearest": bool,
    "opt_linear": bool,
    "weighted": typing.NotRequired[CiftiResampleWeighted1Parameters | None],
})
CiftiResampleSurfacePostdilateParametersTagged = typing.TypedDict('CiftiResampleSurfacePostdilateParametersTagged', {
    "@type": typing.Literal["surface_postdilate"],
    "dilate_mm": float,
    "opt_nearest": bool,
    "opt_linear": bool,
    "weighted": typing.NotRequired[CiftiResampleWeighted1Parameters | None],
})


CiftiResampleFlirtParameters = typing.TypedDict('CiftiResampleFlirtParameters', {
    "@type": typing.NotRequired[typing.Literal["flirt"]],
    "source_volume": str,
    "target_volume": str,
})
CiftiResampleFlirtParametersTagged = typing.TypedDict('CiftiResampleFlirtParametersTagged', {
    "@type": typing.Literal["flirt"],
    "source_volume": str,
    "target_volume": str,
})


CiftiResampleAffineParameters = typing.TypedDict('CiftiResampleAffineParameters', {
    "@type": typing.NotRequired[typing.Literal["affine"]],
    "affine_file": str,
    "flirt": typing.NotRequired[CiftiResampleFlirtParameters | None],
})
CiftiResampleAffineParametersTagged = typing.TypedDict('CiftiResampleAffineParametersTagged', {
    "@type": typing.Literal["affine"],
    "affine_file": str,
    "flirt": typing.NotRequired[CiftiResampleFlirtParameters | None],
})


CiftiResampleWarpfieldParameters = typing.TypedDict('CiftiResampleWarpfieldParameters', {
    "@type": typing.NotRequired[typing.Literal["warpfield"]],
    "warpfield": str,
    "opt_fnirt_source_volume": typing.NotRequired[str | None],
})
CiftiResampleWarpfieldParametersTagged = typing.TypedDict('CiftiResampleWarpfieldParametersTagged', {
    "@type": typing.Literal["warpfield"],
    "warpfield": str,
    "opt_fnirt_source_volume": typing.NotRequired[str | None],
})


CiftiResampleLeftAreaSurfsParameters = typing.TypedDict('CiftiResampleLeftAreaSurfsParameters', {
    "@type": typing.NotRequired[typing.Literal["left_area_surfs"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
CiftiResampleLeftAreaSurfsParametersTagged = typing.TypedDict('CiftiResampleLeftAreaSurfsParametersTagged', {
    "@type": typing.Literal["left_area_surfs"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


CiftiResampleLeftAreaMetricsParameters = typing.TypedDict('CiftiResampleLeftAreaMetricsParameters', {
    "@type": typing.NotRequired[typing.Literal["left_area_metrics"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
CiftiResampleLeftAreaMetricsParametersTagged = typing.TypedDict('CiftiResampleLeftAreaMetricsParametersTagged', {
    "@type": typing.Literal["left_area_metrics"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


CiftiResampleLeftSpheresParameters = typing.TypedDict('CiftiResampleLeftSpheresParameters', {
    "@type": typing.NotRequired[typing.Literal["left_spheres"]],
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "left_area_surfs": typing.NotRequired[CiftiResampleLeftAreaSurfsParameters | None],
    "left_area_metrics": typing.NotRequired[CiftiResampleLeftAreaMetricsParameters | None],
})
CiftiResampleLeftSpheresParametersTagged = typing.TypedDict('CiftiResampleLeftSpheresParametersTagged', {
    "@type": typing.Literal["left_spheres"],
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "left_area_surfs": typing.NotRequired[CiftiResampleLeftAreaSurfsParameters | None],
    "left_area_metrics": typing.NotRequired[CiftiResampleLeftAreaMetricsParameters | None],
})


CiftiResampleRightAreaSurfsParameters = typing.TypedDict('CiftiResampleRightAreaSurfsParameters', {
    "@type": typing.NotRequired[typing.Literal["right_area_surfs"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
CiftiResampleRightAreaSurfsParametersTagged = typing.TypedDict('CiftiResampleRightAreaSurfsParametersTagged', {
    "@type": typing.Literal["right_area_surfs"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


CiftiResampleRightAreaMetricsParameters = typing.TypedDict('CiftiResampleRightAreaMetricsParameters', {
    "@type": typing.NotRequired[typing.Literal["right_area_metrics"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
CiftiResampleRightAreaMetricsParametersTagged = typing.TypedDict('CiftiResampleRightAreaMetricsParametersTagged', {
    "@type": typing.Literal["right_area_metrics"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


CiftiResampleRightSpheresParameters = typing.TypedDict('CiftiResampleRightSpheresParameters', {
    "@type": typing.NotRequired[typing.Literal["right_spheres"]],
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "right_area_surfs": typing.NotRequired[CiftiResampleRightAreaSurfsParameters | None],
    "right_area_metrics": typing.NotRequired[CiftiResampleRightAreaMetricsParameters | None],
})
CiftiResampleRightSpheresParametersTagged = typing.TypedDict('CiftiResampleRightSpheresParametersTagged', {
    "@type": typing.Literal["right_spheres"],
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "right_area_surfs": typing.NotRequired[CiftiResampleRightAreaSurfsParameters | None],
    "right_area_metrics": typing.NotRequired[CiftiResampleRightAreaMetricsParameters | None],
})


CiftiResampleCerebellumAreaSurfsParameters = typing.TypedDict('CiftiResampleCerebellumAreaSurfsParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_area_surfs"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
CiftiResampleCerebellumAreaSurfsParametersTagged = typing.TypedDict('CiftiResampleCerebellumAreaSurfsParametersTagged', {
    "@type": typing.Literal["cerebellum_area_surfs"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


CiftiResampleCerebellumAreaMetricsParameters = typing.TypedDict('CiftiResampleCerebellumAreaMetricsParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_area_metrics"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
CiftiResampleCerebellumAreaMetricsParametersTagged = typing.TypedDict('CiftiResampleCerebellumAreaMetricsParametersTagged', {
    "@type": typing.Literal["cerebellum_area_metrics"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


CiftiResampleCerebellumSpheresParameters = typing.TypedDict('CiftiResampleCerebellumSpheresParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_spheres"]],
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "cerebellum_area_surfs": typing.NotRequired[CiftiResampleCerebellumAreaSurfsParameters | None],
    "cerebellum_area_metrics": typing.NotRequired[CiftiResampleCerebellumAreaMetricsParameters | None],
})
CiftiResampleCerebellumSpheresParametersTagged = typing.TypedDict('CiftiResampleCerebellumSpheresParametersTagged', {
    "@type": typing.Literal["cerebellum_spheres"],
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "cerebellum_area_surfs": typing.NotRequired[CiftiResampleCerebellumAreaSurfsParameters | None],
    "cerebellum_area_metrics": typing.NotRequired[CiftiResampleCerebellumAreaMetricsParameters | None],
})


CiftiResampleParameters = typing.TypedDict('CiftiResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-resample"]],
    "cifti_in": InputPathType,
    "direction": str,
    "cifti_template": InputPathType,
    "template_direction": str,
    "surface_method": str,
    "volume_method": str,
    "cifti_out": str,
    "opt_surface_largest": bool,
    "volume_predilate": typing.NotRequired[CiftiResampleVolumePredilateParameters | None],
    "surface_postdilate": typing.NotRequired[CiftiResampleSurfacePostdilateParameters | None],
    "affine": typing.NotRequired[CiftiResampleAffineParameters | None],
    "warpfield": typing.NotRequired[CiftiResampleWarpfieldParameters | None],
    "left_spheres": typing.NotRequired[CiftiResampleLeftSpheresParameters | None],
    "right_spheres": typing.NotRequired[CiftiResampleRightSpheresParameters | None],
    "cerebellum_spheres": typing.NotRequired[CiftiResampleCerebellumSpheresParameters | None],
})
CiftiResampleParametersTagged = typing.TypedDict('CiftiResampleParametersTagged', {
    "@type": typing.Literal["workbench/cifti-resample"],
    "cifti_in": InputPathType,
    "direction": str,
    "cifti_template": InputPathType,
    "template_direction": str,
    "surface_method": str,
    "volume_method": str,
    "cifti_out": str,
    "opt_surface_largest": bool,
    "volume_predilate": typing.NotRequired[CiftiResampleVolumePredilateParameters | None],
    "surface_postdilate": typing.NotRequired[CiftiResampleSurfacePostdilateParameters | None],
    "affine": typing.NotRequired[CiftiResampleAffineParameters | None],
    "warpfield": typing.NotRequired[CiftiResampleWarpfieldParameters | None],
    "left_spheres": typing.NotRequired[CiftiResampleLeftSpheresParameters | None],
    "right_spheres": typing.NotRequired[CiftiResampleRightSpheresParameters | None],
    "cerebellum_spheres": typing.NotRequired[CiftiResampleCerebellumSpheresParameters | None],
})


def cifti_resample_weighted_params(
    opt_exponent_exponent: float | None = None,
    opt_legacy_cutoff: bool = False,
) -> CiftiResampleWeightedParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_exponent_exponent: specify exponent in weighting function: exponent\
            'n' to use in (1 / (distance ^ n)) as the weighting function (default\
            7).
        opt_legacy_cutoff: use v1.3.2 logic for the kernel cutoff.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "weighted",
        "opt_legacy_cutoff": opt_legacy_cutoff,
    }
    if opt_exponent_exponent is not None:
        params["opt_exponent_exponent"] = opt_exponent_exponent
    return params


def cifti_resample_weighted_cargs(
    params: CiftiResampleWeightedParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-weighted")
    if params.get("opt_exponent_exponent", None) is not None:
        cargs.extend([
            "-exponent",
            str(params.get("opt_exponent_exponent", None))
        ])
    if params.get("opt_legacy_cutoff", False):
        cargs.append("-legacy-cutoff")
    return cargs


def cifti_resample_volume_predilate_params(
    dilate_mm: float,
    opt_nearest: bool = False,
    weighted: CiftiResampleWeightedParameters | None = None,
) -> CiftiResampleVolumePredilateParametersTagged:
    """
    Build parameters.
    
    Args:
        dilate_mm: distance, in mm, to dilate.
        opt_nearest: use nearest value dilation.
        weighted: use weighted dilation (default).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume_predilate",
        "dilate_mm": dilate_mm,
        "opt_nearest": opt_nearest,
    }
    if weighted is not None:
        params["weighted"] = weighted
    return params


def cifti_resample_volume_predilate_cargs(
    params: CiftiResampleVolumePredilateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume-predilate")
    cargs.append(str(params.get("dilate_mm", None)))
    if params.get("opt_nearest", False):
        cargs.append("-nearest")
    if params.get("weighted", None) is not None:
        cargs.extend(cifti_resample_weighted_cargs(params.get("weighted", None), execution))
    return cargs


def cifti_resample_weighted_1_params(
    opt_exponent_exponent: float | None = None,
    opt_legacy_cutoff: bool = False,
) -> CiftiResampleWeighted1ParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_exponent_exponent: specify exponent in weighting function: exponent\
            'n' to use in (area / (distance ^ n)) as the weighting function\
            (default 6).
        opt_legacy_cutoff: use v1.3.2 logic for the kernel cutoff.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "weighted_1",
        "opt_legacy_cutoff": opt_legacy_cutoff,
    }
    if opt_exponent_exponent is not None:
        params["opt_exponent_exponent"] = opt_exponent_exponent
    return params


def cifti_resample_weighted_1_cargs(
    params: CiftiResampleWeighted1Parameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-weighted")
    if params.get("opt_exponent_exponent", None) is not None:
        cargs.extend([
            "-exponent",
            str(params.get("opt_exponent_exponent", None))
        ])
    if params.get("opt_legacy_cutoff", False):
        cargs.append("-legacy-cutoff")
    return cargs


def cifti_resample_surface_postdilate_params(
    dilate_mm: float,
    opt_nearest: bool = False,
    opt_linear: bool = False,
    weighted: CiftiResampleWeighted1Parameters | None = None,
) -> CiftiResampleSurfacePostdilateParametersTagged:
    """
    Build parameters.
    
    Args:
        dilate_mm: distance, in mm, to dilate.
        opt_nearest: use nearest value dilation.
        opt_linear: use linear dilation.
        weighted: use weighted dilation (default for non-label data).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "surface_postdilate",
        "dilate_mm": dilate_mm,
        "opt_nearest": opt_nearest,
        "opt_linear": opt_linear,
    }
    if weighted is not None:
        params["weighted"] = weighted
    return params


def cifti_resample_surface_postdilate_cargs(
    params: CiftiResampleSurfacePostdilateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-surface-postdilate")
    cargs.append(str(params.get("dilate_mm", None)))
    if params.get("opt_nearest", False):
        cargs.append("-nearest")
    if params.get("opt_linear", False):
        cargs.append("-linear")
    if params.get("weighted", None) is not None:
        cargs.extend(cifti_resample_weighted_1_cargs(params.get("weighted", None), execution))
    return cargs


def cifti_resample_flirt_params(
    source_volume: str,
    target_volume: str,
) -> CiftiResampleFlirtParametersTagged:
    """
    Build parameters.
    
    Args:
        source_volume: the source volume used when generating the affine.
        target_volume: the target volume used when generating the affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "flirt",
        "source_volume": source_volume,
        "target_volume": target_volume,
    }
    return params


def cifti_resample_flirt_cargs(
    params: CiftiResampleFlirtParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-flirt")
    cargs.append(params.get("source_volume", None))
    cargs.append(params.get("target_volume", None))
    return cargs


def cifti_resample_affine_params(
    affine_file: str,
    flirt: CiftiResampleFlirtParameters | None = None,
) -> CiftiResampleAffineParametersTagged:
    """
    Build parameters.
    
    Args:
        affine_file: the affine file to use.
        flirt: MUST be used if affine is a flirt affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "affine",
        "affine_file": affine_file,
    }
    if flirt is not None:
        params["flirt"] = flirt
    return params


def cifti_resample_affine_cargs(
    params: CiftiResampleAffineParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-affine")
    cargs.append(params.get("affine_file", None))
    if params.get("flirt", None) is not None:
        cargs.extend(cifti_resample_flirt_cargs(params.get("flirt", None), execution))
    return cargs


def cifti_resample_warpfield_params(
    warpfield: str,
    opt_fnirt_source_volume: str | None = None,
) -> CiftiResampleWarpfieldParametersTagged:
    """
    Build parameters.
    
    Args:
        warpfield: the warpfield to use.
        opt_fnirt_source_volume: MUST be used if using a fnirt warpfield: the\
            source volume used when generating the warpfield.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "warpfield",
        "warpfield": warpfield,
    }
    if opt_fnirt_source_volume is not None:
        params["opt_fnirt_source_volume"] = opt_fnirt_source_volume
    return params


def cifti_resample_warpfield_cargs(
    params: CiftiResampleWarpfieldParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-warpfield")
    cargs.append(params.get("warpfield", None))
    if params.get("opt_fnirt_source_volume", None) is not None:
        cargs.extend([
            "-fnirt",
            params.get("opt_fnirt_source_volume", None)
        ])
    return cargs


def cifti_resample_left_area_surfs_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> CiftiResampleLeftAreaSurfsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a relevant left anatomical surface with current mesh.
        new_area: a relevant left anatomical surface with new mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_area_surfs",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def cifti_resample_left_area_surfs_cargs(
    params: CiftiResampleLeftAreaSurfsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-area-surfs")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def cifti_resample_left_area_metrics_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> CiftiResampleLeftAreaMetricsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a metric file with vertex areas for the current mesh.
        new_area: a metric file with vertex areas for the new mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_area_metrics",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def cifti_resample_left_area_metrics_cargs(
    params: CiftiResampleLeftAreaMetricsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-area-metrics")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def cifti_resample_left_spheres_params(
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    left_area_surfs: CiftiResampleLeftAreaSurfsParameters | None = None,
    left_area_metrics: CiftiResampleLeftAreaMetricsParameters | None = None,
) -> CiftiResampleLeftSpheresParametersTagged:
    """
    Build parameters.
    
    Args:
        current_sphere: a sphere with the same mesh as the current left surface.
        new_sphere: a sphere with the new left mesh that is in register with\
            the current sphere.
        left_area_surfs: specify left surfaces to do vertex area correction\
            based on.
        left_area_metrics: specify left vertex area metrics to do area\
            correction based on.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_spheres",
        "current_sphere": current_sphere,
        "new_sphere": new_sphere,
    }
    if left_area_surfs is not None:
        params["left_area_surfs"] = left_area_surfs
    if left_area_metrics is not None:
        params["left_area_metrics"] = left_area_metrics
    return params


def cifti_resample_left_spheres_cargs(
    params: CiftiResampleLeftSpheresParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-spheres")
    cargs.append(execution.input_file(params.get("current_sphere", None)))
    cargs.append(execution.input_file(params.get("new_sphere", None)))
    if params.get("left_area_surfs", None) is not None:
        cargs.extend(cifti_resample_left_area_surfs_cargs(params.get("left_area_surfs", None), execution))
    if params.get("left_area_metrics", None) is not None:
        cargs.extend(cifti_resample_left_area_metrics_cargs(params.get("left_area_metrics", None), execution))
    return cargs


def cifti_resample_right_area_surfs_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> CiftiResampleRightAreaSurfsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a relevant right anatomical surface with current mesh.
        new_area: a relevant right anatomical surface with new mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_area_surfs",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def cifti_resample_right_area_surfs_cargs(
    params: CiftiResampleRightAreaSurfsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-area-surfs")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def cifti_resample_right_area_metrics_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> CiftiResampleRightAreaMetricsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a metric file with vertex areas for the current mesh.
        new_area: a metric file with vertex areas for the new mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_area_metrics",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def cifti_resample_right_area_metrics_cargs(
    params: CiftiResampleRightAreaMetricsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-area-metrics")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def cifti_resample_right_spheres_params(
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    right_area_surfs: CiftiResampleRightAreaSurfsParameters | None = None,
    right_area_metrics: CiftiResampleRightAreaMetricsParameters | None = None,
) -> CiftiResampleRightSpheresParametersTagged:
    """
    Build parameters.
    
    Args:
        current_sphere: a sphere with the same mesh as the current right\
            surface.
        new_sphere: a sphere with the new right mesh that is in register with\
            the current sphere.
        right_area_surfs: specify right surfaces to do vertex area correction\
            based on.
        right_area_metrics: specify right vertex area metrics to do area\
            correction based on.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_spheres",
        "current_sphere": current_sphere,
        "new_sphere": new_sphere,
    }
    if right_area_surfs is not None:
        params["right_area_surfs"] = right_area_surfs
    if right_area_metrics is not None:
        params["right_area_metrics"] = right_area_metrics
    return params


def cifti_resample_right_spheres_cargs(
    params: CiftiResampleRightSpheresParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-spheres")
    cargs.append(execution.input_file(params.get("current_sphere", None)))
    cargs.append(execution.input_file(params.get("new_sphere", None)))
    if params.get("right_area_surfs", None) is not None:
        cargs.extend(cifti_resample_right_area_surfs_cargs(params.get("right_area_surfs", None), execution))
    if params.get("right_area_metrics", None) is not None:
        cargs.extend(cifti_resample_right_area_metrics_cargs(params.get("right_area_metrics", None), execution))
    return cargs


def cifti_resample_cerebellum_area_surfs_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> CiftiResampleCerebellumAreaSurfsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a relevant cerebellum anatomical surface with current\
            mesh.
        new_area: a relevant cerebellum anatomical surface with new mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_area_surfs",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def cifti_resample_cerebellum_area_surfs_cargs(
    params: CiftiResampleCerebellumAreaSurfsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-area-surfs")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def cifti_resample_cerebellum_area_metrics_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> CiftiResampleCerebellumAreaMetricsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a metric file with vertex areas for the current mesh.
        new_area: a metric file with vertex areas for the new mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_area_metrics",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def cifti_resample_cerebellum_area_metrics_cargs(
    params: CiftiResampleCerebellumAreaMetricsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-area-metrics")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def cifti_resample_cerebellum_spheres_params(
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    cerebellum_area_surfs: CiftiResampleCerebellumAreaSurfsParameters | None = None,
    cerebellum_area_metrics: CiftiResampleCerebellumAreaMetricsParameters | None = None,
) -> CiftiResampleCerebellumSpheresParametersTagged:
    """
    Build parameters.
    
    Args:
        current_sphere: a sphere with the same mesh as the current cerebellum\
            surface.
        new_sphere: a sphere with the new cerebellum mesh that is in register\
            with the current sphere.
        cerebellum_area_surfs: specify cerebellum surfaces to do vertex area\
            correction based on.
        cerebellum_area_metrics: specify cerebellum vertex area metrics to do\
            area correction based on.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_spheres",
        "current_sphere": current_sphere,
        "new_sphere": new_sphere,
    }
    if cerebellum_area_surfs is not None:
        params["cerebellum_area_surfs"] = cerebellum_area_surfs
    if cerebellum_area_metrics is not None:
        params["cerebellum_area_metrics"] = cerebellum_area_metrics
    return params


def cifti_resample_cerebellum_spheres_cargs(
    params: CiftiResampleCerebellumSpheresParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-spheres")
    cargs.append(execution.input_file(params.get("current_sphere", None)))
    cargs.append(execution.input_file(params.get("new_sphere", None)))
    if params.get("cerebellum_area_surfs", None) is not None:
        cargs.extend(cifti_resample_cerebellum_area_surfs_cargs(params.get("cerebellum_area_surfs", None), execution))
    if params.get("cerebellum_area_metrics", None) is not None:
        cargs.extend(cifti_resample_cerebellum_area_metrics_cargs(params.get("cerebellum_area_metrics", None), execution))
    return cargs


class CiftiResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_resample_params(
    cifti_in: InputPathType,
    direction: str,
    cifti_template: InputPathType,
    template_direction: str,
    surface_method: str,
    volume_method: str,
    cifti_out: str,
    opt_surface_largest: bool = False,
    volume_predilate: CiftiResampleVolumePredilateParameters | None = None,
    surface_postdilate: CiftiResampleSurfacePostdilateParameters | None = None,
    affine: CiftiResampleAffineParameters | None = None,
    warpfield: CiftiResampleWarpfieldParameters | None = None,
    left_spheres: CiftiResampleLeftSpheresParameters | None = None,
    right_spheres: CiftiResampleRightSpheresParameters | None = None,
    cerebellum_spheres: CiftiResampleCerebellumSpheresParameters | None = None,
) -> CiftiResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the cifti file to resample.
        direction: the direction of the input that should be resampled, ROW or\
            COLUMN.
        cifti_template: a cifti file containing the cifti space to resample to.
        template_direction: the direction of the template to use as the\
            resampling space, ROW or COLUMN.
        surface_method: specify a surface resampling method.
        volume_method: specify a volume interpolation method.
        cifti_out: the output cifti file.
        opt_surface_largest: use largest weight instead of weighted average or\
            popularity when doing surface resampling.
        volume_predilate: dilate the volume components before resampling.
        surface_postdilate: dilate the surface components after resampling.
        affine: use an affine transformation on the volume components.
        warpfield: use a warpfield on the volume components.
        left_spheres: specify spheres for left surface resampling.
        right_spheres: specify spheres for right surface resampling.
        cerebellum_spheres: specify spheres for cerebellum surface resampling.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-resample",
        "cifti_in": cifti_in,
        "direction": direction,
        "cifti_template": cifti_template,
        "template_direction": template_direction,
        "surface_method": surface_method,
        "volume_method": volume_method,
        "cifti_out": cifti_out,
        "opt_surface_largest": opt_surface_largest,
    }
    if volume_predilate is not None:
        params["volume_predilate"] = volume_predilate
    if surface_postdilate is not None:
        params["surface_postdilate"] = surface_postdilate
    if affine is not None:
        params["affine"] = affine
    if warpfield is not None:
        params["warpfield"] = warpfield
    if left_spheres is not None:
        params["left_spheres"] = left_spheres
    if right_spheres is not None:
        params["right_spheres"] = right_spheres
    if cerebellum_spheres is not None:
        params["cerebellum_spheres"] = cerebellum_spheres
    return params


def cifti_resample_cargs(
    params: CiftiResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-resample")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("direction", None))
    cargs.append(execution.input_file(params.get("cifti_template", None)))
    cargs.append(params.get("template_direction", None))
    cargs.append(params.get("surface_method", None))
    cargs.append(params.get("volume_method", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_surface_largest", False):
        cargs.append("-surface-largest")
    if params.get("volume_predilate", None) is not None:
        cargs.extend(cifti_resample_volume_predilate_cargs(params.get("volume_predilate", None), execution))
    if params.get("surface_postdilate", None) is not None:
        cargs.extend(cifti_resample_surface_postdilate_cargs(params.get("surface_postdilate", None), execution))
    if params.get("affine", None) is not None:
        cargs.extend(cifti_resample_affine_cargs(params.get("affine", None), execution))
    if params.get("warpfield", None) is not None:
        cargs.extend(cifti_resample_warpfield_cargs(params.get("warpfield", None), execution))
    if params.get("left_spheres", None) is not None:
        cargs.extend(cifti_resample_left_spheres_cargs(params.get("left_spheres", None), execution))
    if params.get("right_spheres", None) is not None:
        cargs.extend(cifti_resample_right_spheres_cargs(params.get("right_spheres", None), execution))
    if params.get("cerebellum_spheres", None) is not None:
        cargs.extend(cifti_resample_cerebellum_spheres_cargs(params.get("cerebellum_spheres", None), execution))
    return cargs


def cifti_resample_outputs(
    params: CiftiResampleParameters,
    execution: Execution,
) -> CiftiResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiResampleOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_resample_execute(
    params: CiftiResampleParameters,
    runner: Runner | None = None,
) -> CiftiResampleOutputs:
    """
    cifti-resample
    
    Resample a cifti file to a new cifti space.
    
    Resample cifti data to a different brainordinate space. Use COLUMN for the
    direction to resample dscalar, dlabel, or dtseries. Resampling both
    dimensions of a dconn requires running this command twice, once with COLUMN
    and once with ROW. If you are resampling a dconn and your machine has a
    large amount of memory, you might consider using
    -cifti-resample-dconn-memory to avoid writing and rereading an intermediate
    file. The <template-direction> argument should usually be COLUMN, as
    dtseries, dscalar, and dlabel all have brainordinates on that direction. If
    spheres are not specified for a surface structure which exists in the cifti
    files, its data is copied without resampling or dilation. Dilation is done
    with the 'nearest' method, and is done on <new-sphere> for surface data.
    Volume components are padded before dilation so that dilation doesn't run
    into the edge of the component bounding box. If neither -affine nor
    -warpfield are specified, the identity transform is assumed for the volume
    data.
    
    The recommended resampling methods are ADAP_BARY_AREA and CUBIC (cubic
    spline), except for label data which should use ADAP_BARY_AREA and
    ENCLOSING_VOXEL. Using ADAP_BARY_AREA requires specifying an area option to
    each used -*-spheres option.
    
    The <volume-method> argument must be one of the following:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR
    
    The <surface-method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = cifti_resample_cargs(params, execution)
    ret = cifti_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_resample(
    cifti_in: InputPathType,
    direction: str,
    cifti_template: InputPathType,
    template_direction: str,
    surface_method: str,
    volume_method: str,
    cifti_out: str,
    opt_surface_largest: bool = False,
    volume_predilate: CiftiResampleVolumePredilateParameters | None = None,
    surface_postdilate: CiftiResampleSurfacePostdilateParameters | None = None,
    affine: CiftiResampleAffineParameters | None = None,
    warpfield: CiftiResampleWarpfieldParameters | None = None,
    left_spheres: CiftiResampleLeftSpheresParameters | None = None,
    right_spheres: CiftiResampleRightSpheresParameters | None = None,
    cerebellum_spheres: CiftiResampleCerebellumSpheresParameters | None = None,
    runner: Runner | None = None,
) -> CiftiResampleOutputs:
    """
    cifti-resample
    
    Resample a cifti file to a new cifti space.
    
    Resample cifti data to a different brainordinate space. Use COLUMN for the
    direction to resample dscalar, dlabel, or dtseries. Resampling both
    dimensions of a dconn requires running this command twice, once with COLUMN
    and once with ROW. If you are resampling a dconn and your machine has a
    large amount of memory, you might consider using
    -cifti-resample-dconn-memory to avoid writing and rereading an intermediate
    file. The <template-direction> argument should usually be COLUMN, as
    dtseries, dscalar, and dlabel all have brainordinates on that direction. If
    spheres are not specified for a surface structure which exists in the cifti
    files, its data is copied without resampling or dilation. Dilation is done
    with the 'nearest' method, and is done on <new-sphere> for surface data.
    Volume components are padded before dilation so that dilation doesn't run
    into the edge of the component bounding box. If neither -affine nor
    -warpfield are specified, the identity transform is assumed for the volume
    data.
    
    The recommended resampling methods are ADAP_BARY_AREA and CUBIC (cubic
    spline), except for label data which should use ADAP_BARY_AREA and
    ENCLOSING_VOXEL. Using ADAP_BARY_AREA requires specifying an area option to
    each used -*-spheres option.
    
    The <volume-method> argument must be one of the following:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR
    
    The <surface-method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the cifti file to resample.
        direction: the direction of the input that should be resampled, ROW or\
            COLUMN.
        cifti_template: a cifti file containing the cifti space to resample to.
        template_direction: the direction of the template to use as the\
            resampling space, ROW or COLUMN.
        surface_method: specify a surface resampling method.
        volume_method: specify a volume interpolation method.
        cifti_out: the output cifti file.
        opt_surface_largest: use largest weight instead of weighted average or\
            popularity when doing surface resampling.
        volume_predilate: dilate the volume components before resampling.
        surface_postdilate: dilate the surface components after resampling.
        affine: use an affine transformation on the volume components.
        warpfield: use a warpfield on the volume components.
        left_spheres: specify spheres for left surface resampling.
        right_spheres: specify spheres for right surface resampling.
        cerebellum_spheres: specify spheres for cerebellum surface resampling.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiResampleOutputs`).
    """
    params = cifti_resample_params(
        cifti_in=cifti_in,
        direction=direction,
        cifti_template=cifti_template,
        template_direction=template_direction,
        surface_method=surface_method,
        volume_method=volume_method,
        cifti_out=cifti_out,
        opt_surface_largest=opt_surface_largest,
        volume_predilate=volume_predilate,
        surface_postdilate=surface_postdilate,
        affine=affine,
        warpfield=warpfield,
        left_spheres=left_spheres,
        right_spheres=right_spheres,
        cerebellum_spheres=cerebellum_spheres,
    )
    return cifti_resample_execute(params, runner)


__all__ = [
    "CIFTI_RESAMPLE_METADATA",
    "CiftiResampleOutputs",
    "cifti_resample",
    "cifti_resample_affine_params",
    "cifti_resample_cerebellum_area_metrics_params",
    "cifti_resample_cerebellum_area_surfs_params",
    "cifti_resample_cerebellum_spheres_params",
    "cifti_resample_execute",
    "cifti_resample_flirt_params",
    "cifti_resample_left_area_metrics_params",
    "cifti_resample_left_area_surfs_params",
    "cifti_resample_left_spheres_params",
    "cifti_resample_params",
    "cifti_resample_right_area_metrics_params",
    "cifti_resample_right_area_surfs_params",
    "cifti_resample_right_spheres_params",
    "cifti_resample_surface_postdilate_params",
    "cifti_resample_volume_predilate_params",
    "cifti_resample_warpfield_params",
    "cifti_resample_weighted_1_params",
    "cifti_resample_weighted_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

LABEL_DILATE_METADATA = Metadata(
    id="73edd274bc940fb62891aa8ff3534fdafc214402.boutiques",
    name="label-dilate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


LabelDilateParameters = typing.TypedDict('LabelDilateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/label-dilate"]],
    "label": InputPathType,
    "surface": InputPathType,
    "dilate_dist": float,
    "label_out": str,
    "opt_bad_vertex_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
LabelDilateParametersTagged = typing.TypedDict('LabelDilateParametersTagged', {
    "@type": typing.Literal["workbench/label-dilate"],
    "label": InputPathType,
    "surface": InputPathType,
    "dilate_dist": float,
    "label_out": str,
    "opt_bad_vertex_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


class LabelDilateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `LabelDilateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""


def label_dilate_params(
    label: InputPathType,
    surface: InputPathType,
    dilate_dist: float,
    label_out: str,
    opt_bad_vertex_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
) -> LabelDilateParametersTagged:
    """
    Build parameters.
    
    Args:
        label: the input label.
        surface: the surface to dilate on.
        dilate_dist: distance in mm to dilate the labels.
        label_out: the output label file.
        opt_bad_vertex_roi_roi_metric: specify an roi of vertices to overwrite,\
            rather than vertices with the unlabeled key: metric file, positive\
            values denote vertices to have their values replaced.
        opt_column_column: select a single column to dilate: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/label-dilate",
        "label": label,
        "surface": surface,
        "dilate_dist": dilate_dist,
        "label_out": label_out,
    }
    if opt_bad_vertex_roi_roi_metric is not None:
        params["opt_bad_vertex_roi_roi_metric"] = opt_bad_vertex_roi_roi_metric
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def label_dilate_cargs(
    params: LabelDilateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-dilate")
    cargs.append(execution.input_file(params.get("label", None)))
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(str(params.get("dilate_dist", None)))
    cargs.append(params.get("label_out", None))
    if params.get("opt_bad_vertex_roi_roi_metric", None) is not None:
        cargs.extend([
            "-bad-vertex-roi",
            execution.input_file(params.get("opt_bad_vertex_roi_roi_metric", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    return cargs


def label_dilate_outputs(
    params: LabelDilateParameters,
    execution: Execution,
) -> LabelDilateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = LabelDilateOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(params.get("label_out", None)),
    )
    return ret


def label_dilate_execute(
    params: LabelDilateParameters,
    runner: Runner | None = None,
) -> LabelDilateOutputs:
    """
    label-dilate
    
    Dilate a label file.
    
    Fills in label information for all vertices designated as bad, up to the
    specified distance away from other labels. If -bad-vertex-roi is specified,
    all vertices, including those with the unlabeled key, are good, except for
    vertices with a positive value in the ROI. If it is not specified, only
    vertices with the unlabeled key are bad.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelDilateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_DILATE_METADATA)
    params = execution.params(params)
    cargs = label_dilate_cargs(params, execution)
    ret = label_dilate_outputs(params, execution)
    execution.run(cargs)
    return ret


def label_dilate(
    label: InputPathType,
    surface: InputPathType,
    dilate_dist: float,
    label_out: str,
    opt_bad_vertex_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> LabelDilateOutputs:
    """
    label-dilate
    
    Dilate a label file.
    
    Fills in label information for all vertices designated as bad, up to the
    specified distance away from other labels. If -bad-vertex-roi is specified,
    all vertices, including those with the unlabeled key, are good, except for
    vertices with a positive value in the ROI. If it is not specified, only
    vertices with the unlabeled key are bad.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label: the input label.
        surface: the surface to dilate on.
        dilate_dist: distance in mm to dilate the labels.
        label_out: the output label file.
        opt_bad_vertex_roi_roi_metric: specify an roi of vertices to overwrite,\
            rather than vertices with the unlabeled key: metric file, positive\
            values denote vertices to have their values replaced.
        opt_column_column: select a single column to dilate: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelDilateOutputs`).
    """
    params = label_dilate_params(
        label=label,
        surface=surface,
        dilate_dist=dilate_dist,
        label_out=label_out,
        opt_bad_vertex_roi_roi_metric=opt_bad_vertex_roi_roi_metric,
        opt_column_column=opt_column_column,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
    )
    return label_dilate_execute(params, runner)


__all__ = [
    "LABEL_DILATE_METADATA",
    "LabelDilateOutputs",
    "label_dilate",
    "label_dilate_execute",
    "label_dilate_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_ERODE_METADATA = Metadata(
    id="13e8b65243f7eb68a8e3480c1d899b0d9d55567e.boutiques",
    name="metric-erode",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricErodeParameters = typing.TypedDict('MetricErodeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-erode"]],
    "metric": InputPathType,
    "surface": InputPathType,
    "distance": float,
    "metric_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
MetricErodeParametersTagged = typing.TypedDict('MetricErodeParametersTagged', {
    "@type": typing.Literal["workbench/metric-erode"],
    "metric": InputPathType,
    "surface": InputPathType,
    "distance": float,
    "metric_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


class MetricErodeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricErodeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_erode_params(
    metric: InputPathType,
    surface: InputPathType,
    distance: float,
    metric_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
) -> MetricErodeParametersTagged:
    """
    Build parameters.
    
    Args:
        metric: the metric file to erode.
        surface: the surface to compute on.
        distance: distance in mm to erode.
        metric_out: the output metric.
        opt_roi_roi_metric: assume values outside this roi are nonzero: metric\
            file, positive values denote vertices that have data.
        opt_column_column: select a single column to erode: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-erode",
        "metric": metric,
        "surface": surface,
        "distance": distance,
        "metric_out": metric_out,
    }
    if opt_roi_roi_metric is not None:
        params["opt_roi_roi_metric"] = opt_roi_roi_metric
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def metric_erode_cargs(
    params: MetricErodeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-erode")
    cargs.append(execution.input_file(params.get("metric", None)))
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(str(params.get("distance", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_roi_roi_metric", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_metric", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    return cargs


def metric_erode_outputs(
    params: MetricErodeParameters,
    execution: Execution,
) -> MetricErodeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricErodeOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_erode_execute(
    params: MetricErodeParameters,
    runner: Runner | None = None,
) -> MetricErodeOutputs:
    """
    metric-erode
    
    Erode a metric file.
    
    Around each vertex with a value of zero, set surrounding vertices to zero.
    The surrounding vertices are all immediate neighbors and all vertices within
    the specified distance.
    
    Note that the -corrected-areas option uses an approximate correction for
    distance along the surface.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricErodeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_ERODE_METADATA)
    params = execution.params(params)
    cargs = metric_erode_cargs(params, execution)
    ret = metric_erode_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_erode(
    metric: InputPathType,
    surface: InputPathType,
    distance: float,
    metric_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> MetricErodeOutputs:
    """
    metric-erode
    
    Erode a metric file.
    
    Around each vertex with a value of zero, set surrounding vertices to zero.
    The surrounding vertices are all immediate neighbors and all vertices within
    the specified distance.
    
    Note that the -corrected-areas option uses an approximate correction for
    distance along the surface.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric: the metric file to erode.
        surface: the surface to compute on.
        distance: distance in mm to erode.
        metric_out: the output metric.
        opt_roi_roi_metric: assume values outside this roi are nonzero: metric\
            file, positive values denote vertices that have data.
        opt_column_column: select a single column to erode: the column number\
            or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricErodeOutputs`).
    """
    params = metric_erode_params(
        metric=metric,
        surface=surface,
        distance=distance,
        metric_out=metric_out,
        opt_roi_roi_metric=opt_roi_roi_metric,
        opt_column_column=opt_column_column,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
    )
    return metric_erode_execute(params, runner)


__all__ = [
    "METRIC_ERODE_METADATA",
    "MetricErodeOutputs",
    "metric_erode",
    "metric_erode_execute",
    "metric_erode_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CREATE_SCALAR_SERIES_METADATA = Metadata(
    id="89382f5dba10644cb62354103467cd5b9bd291f2.boutiques",
    name="cifti-create-scalar-series",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiCreateScalarSeriesSeriesParameters = typing.TypedDict('CiftiCreateScalarSeriesSeriesParameters', {
    "@type": typing.NotRequired[typing.Literal["series"]],
    "unit": str,
    "start": float,
    "step": float,
})
CiftiCreateScalarSeriesSeriesParametersTagged = typing.TypedDict('CiftiCreateScalarSeriesSeriesParametersTagged', {
    "@type": typing.Literal["series"],
    "unit": str,
    "start": float,
    "step": float,
})


CiftiCreateScalarSeriesParameters = typing.TypedDict('CiftiCreateScalarSeriesParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-create-scalar-series"]],
    "input": str,
    "cifti_out": str,
    "opt_transpose": bool,
    "opt_name_file_file": typing.NotRequired[str | None],
    "series": typing.NotRequired[CiftiCreateScalarSeriesSeriesParameters | None],
})
CiftiCreateScalarSeriesParametersTagged = typing.TypedDict('CiftiCreateScalarSeriesParametersTagged', {
    "@type": typing.Literal["workbench/cifti-create-scalar-series"],
    "input": str,
    "cifti_out": str,
    "opt_transpose": bool,
    "opt_name_file_file": typing.NotRequired[str | None],
    "series": typing.NotRequired[CiftiCreateScalarSeriesSeriesParameters | None],
})


def cifti_create_scalar_series_series_params(
    unit: str,
    start: float,
    step: float,
) -> CiftiCreateScalarSeriesSeriesParametersTagged:
    """
    Build parameters.
    
    Args:
        unit: the unit to use.
        start: the value at the first series point.
        step: the interval between series points.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "series",
        "unit": unit,
        "start": start,
        "step": step,
    }
    return params


def cifti_create_scalar_series_series_cargs(
    params: CiftiCreateScalarSeriesSeriesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-series")
    cargs.append(params.get("unit", None))
    cargs.append(str(params.get("start", None)))
    cargs.append(str(params.get("step", None)))
    return cargs


class CiftiCreateScalarSeriesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiCreateScalarSeriesParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_create_scalar_series_params(
    input_: str,
    cifti_out: str,
    opt_transpose: bool = False,
    opt_name_file_file: str | None = None,
    series: CiftiCreateScalarSeriesSeriesParameters | None = None,
) -> CiftiCreateScalarSeriesParametersTagged:
    """
    Build parameters.
    
    Args:
        input_: input file.
        cifti_out: output cifti file.
        opt_transpose: use if the rows of the text file are along the scalar\
            dimension.
        opt_name_file_file: use a text file to set names on scalar dimension:\
            text file containing names, one per line.
        series: set the units and values of the series.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-create-scalar-series",
        "input": input_,
        "cifti_out": cifti_out,
        "opt_transpose": opt_transpose,
    }
    if opt_name_file_file is not None:
        params["opt_name_file_file"] = opt_name_file_file
    if series is not None:
        params["series"] = series
    return params


def cifti_create_scalar_series_cargs(
    params: CiftiCreateScalarSeriesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-scalar-series")
    cargs.append(params.get("input", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_transpose", False):
        cargs.append("-transpose")
    if params.get("opt_name_file_file", None) is not None:
        cargs.extend([
            "-name-file",
            params.get("opt_name_file_file", None)
        ])
    if params.get("series", None) is not None:
        cargs.extend(cifti_create_scalar_series_series_cargs(params.get("series", None), execution))
    return cargs


def cifti_create_scalar_series_outputs(
    params: CiftiCreateScalarSeriesParameters,
    execution: Execution,
) -> CiftiCreateScalarSeriesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiCreateScalarSeriesOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_create_scalar_series_execute(
    params: CiftiCreateScalarSeriesParameters,
    runner: Runner | None = None,
) -> CiftiCreateScalarSeriesOutputs:
    """
    cifti-create-scalar-series
    
    Import series data into cifti.
    
    Convert a text file containing series of equal length into a cifti file. The
    text file should have lines made up of numbers separated by whitespace, with
    no extra newlines between lines.
    
    The <unit> argument must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateScalarSeriesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_SCALAR_SERIES_METADATA)
    params = execution.params(params)
    cargs = cifti_create_scalar_series_cargs(params, execution)
    ret = cifti_create_scalar_series_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_create_scalar_series(
    input_: str,
    cifti_out: str,
    opt_transpose: bool = False,
    opt_name_file_file: str | None = None,
    series: CiftiCreateScalarSeriesSeriesParameters | None = None,
    runner: Runner | None = None,
) -> CiftiCreateScalarSeriesOutputs:
    """
    cifti-create-scalar-series
    
    Import series data into cifti.
    
    Convert a text file containing series of equal length into a cifti file. The
    text file should have lines made up of numbers separated by whitespace, with
    no extra newlines between lines.
    
    The <unit> argument must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_: input file.
        cifti_out: output cifti file.
        opt_transpose: use if the rows of the text file are along the scalar\
            dimension.
        opt_name_file_file: use a text file to set names on scalar dimension:\
            text file containing names, one per line.
        series: set the units and values of the series.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateScalarSeriesOutputs`).
    """
    params = cifti_create_scalar_series_params(
        input_=input_,
        cifti_out=cifti_out,
        opt_transpose=opt_transpose,
        opt_name_file_file=opt_name_file_file,
        series=series,
    )
    return cifti_create_scalar_series_execute(params, runner)


__all__ = [
    "CIFTI_CREATE_SCALAR_SERIES_METADATA",
    "CiftiCreateScalarSeriesOutputs",
    "cifti_create_scalar_series",
    "cifti_create_scalar_series_execute",
    "cifti_create_scalar_series_params",
    "cifti_create_scalar_series_series_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_WARPFIELD_AFFINE_REGRESSION_METADATA = Metadata(
    id="e61fbc4ce12b2c7a4b5f716606949064603e9c48.boutiques",
    name="volume-warpfield-affine-regression",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeWarpfieldAffineRegressionFlirtOutParameters = typing.TypedDict('VolumeWarpfieldAffineRegressionFlirtOutParameters', {
    "@type": typing.NotRequired[typing.Literal["flirt_out"]],
    "source_volume": str,
    "target_volume": str,
})
VolumeWarpfieldAffineRegressionFlirtOutParametersTagged = typing.TypedDict('VolumeWarpfieldAffineRegressionFlirtOutParametersTagged', {
    "@type": typing.Literal["flirt_out"],
    "source_volume": str,
    "target_volume": str,
})


VolumeWarpfieldAffineRegressionParameters = typing.TypedDict('VolumeWarpfieldAffineRegressionParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-warpfield-affine-regression"]],
    "warpfield": str,
    "affine_out": str,
    "opt_roi_roi_vol": typing.NotRequired[InputPathType | None],
    "opt_fnirt_source_volume": typing.NotRequired[str | None],
    "flirt_out": typing.NotRequired[VolumeWarpfieldAffineRegressionFlirtOutParameters | None],
})
VolumeWarpfieldAffineRegressionParametersTagged = typing.TypedDict('VolumeWarpfieldAffineRegressionParametersTagged', {
    "@type": typing.Literal["workbench/volume-warpfield-affine-regression"],
    "warpfield": str,
    "affine_out": str,
    "opt_roi_roi_vol": typing.NotRequired[InputPathType | None],
    "opt_fnirt_source_volume": typing.NotRequired[str | None],
    "flirt_out": typing.NotRequired[VolumeWarpfieldAffineRegressionFlirtOutParameters | None],
})


def volume_warpfield_affine_regression_flirt_out_params(
    source_volume: str,
    target_volume: str,
) -> VolumeWarpfieldAffineRegressionFlirtOutParametersTagged:
    """
    Build parameters.
    
    Args:
        source_volume: the volume you want to apply the transform to.
        target_volume: the target space you want the transformed volume to\
            match.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "flirt_out",
        "source_volume": source_volume,
        "target_volume": target_volume,
    }
    return params


def volume_warpfield_affine_regression_flirt_out_cargs(
    params: VolumeWarpfieldAffineRegressionFlirtOutParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-flirt-out")
    cargs.append(params.get("source_volume", None))
    cargs.append(params.get("target_volume", None))
    return cargs


class VolumeWarpfieldAffineRegressionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeWarpfieldAffineRegressionParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_warpfield_affine_regression_params(
    warpfield: str,
    affine_out: str,
    opt_roi_roi_vol: InputPathType | None = None,
    opt_fnirt_source_volume: str | None = None,
    flirt_out: VolumeWarpfieldAffineRegressionFlirtOutParameters | None = None,
) -> VolumeWarpfieldAffineRegressionParametersTagged:
    """
    Build parameters.
    
    Args:
        warpfield: the input warpfield.
        affine_out: output - the output affine file.
        opt_roi_roi_vol: only consider voxels within a mask (e.g., a brain\
            mask): the mask volume.
        opt_fnirt_source_volume: input is a fnirt warpfield: the source volume\
            used when generating the fnirt warpfield.
        flirt_out: write output as a flirt matrix rather than a world\
            coordinate transform.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-warpfield-affine-regression",
        "warpfield": warpfield,
        "affine_out": affine_out,
    }
    if opt_roi_roi_vol is not None:
        params["opt_roi_roi_vol"] = opt_roi_roi_vol
    if opt_fnirt_source_volume is not None:
        params["opt_fnirt_source_volume"] = opt_fnirt_source_volume
    if flirt_out is not None:
        params["flirt_out"] = flirt_out
    return params


def volume_warpfield_affine_regression_cargs(
    params: VolumeWarpfieldAffineRegressionParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-warpfield-affine-regression")
    cargs.append(params.get("warpfield", None))
    cargs.append(params.get("affine_out", None))
    if params.get("opt_roi_roi_vol", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_vol", None))
        ])
    if params.get("opt_fnirt_source_volume", None) is not None:
        cargs.extend([
            "-fnirt",
            params.get("opt_fnirt_source_volume", None)
        ])
    if params.get("flirt_out", None) is not None:
        cargs.extend(volume_warpfield_affine_regression_flirt_out_cargs(params.get("flirt_out", None), execution))
    return cargs


def volume_warpfield_affine_regression_outputs(
    params: VolumeWarpfieldAffineRegressionParameters,
    execution: Execution,
) -> VolumeWarpfieldAffineRegressionOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeWarpfieldAffineRegressionOutputs(
        root=execution.output_file("."),
    )
    return ret


def volume_warpfield_affine_regression_execute(
    params: VolumeWarpfieldAffineRegressionParameters,
    runner: Runner | None = None,
) -> VolumeWarpfieldAffineRegressionOutputs:
    """
    volume-warpfield-affine-regression
    
    Regress affine from warpfield.
    
    For all voxels in the warpfield, do a regression that predicts the post-warp
    coordinate from the source coordinate. When -roi is specified, only consider
    voxels with a value greater than 0 in <roi-vol>.
    
    The default is to expect the warpfield to be in relative world coordinates
    (mm space), and to write the output as a world affine (mm space to mm
    space). If you are using FSL-created files and utilities, specify -fnirt and
    -flirt as needed, as their coordinate conventions are different.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeWarpfieldAffineRegressionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_WARPFIELD_AFFINE_REGRESSION_METADATA)
    params = execution.params(params)
    cargs = volume_warpfield_affine_regression_cargs(params, execution)
    ret = volume_warpfield_affine_regression_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_warpfield_affine_regression(
    warpfield: str,
    affine_out: str,
    opt_roi_roi_vol: InputPathType | None = None,
    opt_fnirt_source_volume: str | None = None,
    flirt_out: VolumeWarpfieldAffineRegressionFlirtOutParameters | None = None,
    runner: Runner | None = None,
) -> VolumeWarpfieldAffineRegressionOutputs:
    """
    volume-warpfield-affine-regression
    
    Regress affine from warpfield.
    
    For all voxels in the warpfield, do a regression that predicts the post-warp
    coordinate from the source coordinate. When -roi is specified, only consider
    voxels with a value greater than 0 in <roi-vol>.
    
    The default is to expect the warpfield to be in relative world coordinates
    (mm space), and to write the output as a world affine (mm space to mm
    space). If you are using FSL-created files and utilities, specify -fnirt and
    -flirt as needed, as their coordinate conventions are different.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        warpfield: the input warpfield.
        affine_out: output - the output affine file.
        opt_roi_roi_vol: only consider voxels within a mask (e.g., a brain\
            mask): the mask volume.
        opt_fnirt_source_volume: input is a fnirt warpfield: the source volume\
            used when generating the fnirt warpfield.
        flirt_out: write output as a flirt matrix rather than a world\
            coordinate transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeWarpfieldAffineRegressionOutputs`).
    """
    params = volume_warpfield_affine_regression_params(
        warpfield=warpfield,
        affine_out=affine_out,
        opt_roi_roi_vol=opt_roi_roi_vol,
        opt_fnirt_source_volume=opt_fnirt_source_volume,
        flirt_out=flirt_out,
    )
    return volume_warpfield_affine_regression_execute(params, runner)


__all__ = [
    "VOLUME_WARPFIELD_AFFINE_REGRESSION_METADATA",
    "VolumeWarpfieldAffineRegressionOutputs",
    "volume_warpfield_affine_regression",
    "volume_warpfield_affine_regression_execute",
    "volume_warpfield_affine_regression_flirt_out_params",
    "volume_warpfield_affine_regression_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METADATA_STRING_REPLACE_METADATA = Metadata(
    id="64839919f0abce1435877772c78bd57e1db01436.boutiques",
    name="metadata-string-replace",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetadataStringReplaceParameters = typing.TypedDict('MetadataStringReplaceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metadata-string-replace"]],
    "input_file": str,
    "find_string": str,
    "replace_string": str,
    "output_file": str,
    "opt_case_insensitive": bool,
})
MetadataStringReplaceParametersTagged = typing.TypedDict('MetadataStringReplaceParametersTagged', {
    "@type": typing.Literal["workbench/metadata-string-replace"],
    "input_file": str,
    "find_string": str,
    "replace_string": str,
    "output_file": str,
    "opt_case_insensitive": bool,
})


class MetadataStringReplaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetadataStringReplaceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def metadata_string_replace_params(
    input_file: str,
    find_string: str,
    replace_string: str,
    output_file: str,
    opt_case_insensitive: bool = False,
) -> MetadataStringReplaceParametersTagged:
    """
    Build parameters.
    
    Args:
        input_file: the file to replace metadata in.
        find_string: the string to find.
        replace_string: the string to replace <find-string> with.
        output_file: output - the name to save the modified file as.
        opt_case_insensitive: match with case variation also.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metadata-string-replace",
        "input_file": input_file,
        "find_string": find_string,
        "replace_string": replace_string,
        "output_file": output_file,
        "opt_case_insensitive": opt_case_insensitive,
    }
    return params


def metadata_string_replace_cargs(
    params: MetadataStringReplaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metadata-string-replace")
    cargs.append(params.get("input_file", None))
    cargs.append(params.get("find_string", None))
    cargs.append(params.get("replace_string", None))
    cargs.append(params.get("output_file", None))
    if params.get("opt_case_insensitive", False):
        cargs.append("-case-insensitive")
    return cargs


def metadata_string_replace_outputs(
    params: MetadataStringReplaceParameters,
    execution: Execution,
) -> MetadataStringReplaceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetadataStringReplaceOutputs(
        root=execution.output_file("."),
    )
    return ret


def metadata_string_replace_execute(
    params: MetadataStringReplaceParameters,
    runner: Runner | None = None,
) -> MetadataStringReplaceOutputs:
    """
    metadata-string-replace
    
    Replace a string in all metadata of a file.
    
    Replaces all occurrences of <find-string> in the metadata and map names of
    <input-file> with <replace-string>.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetadataStringReplaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METADATA_STRING_REPLACE_METADATA)
    params = execution.params(params)
    cargs = metadata_string_replace_cargs(params, execution)
    ret = metadata_string_replace_outputs(params, execution)
    execution.run(cargs)
    return ret


def metadata_string_replace(
    input_file: str,
    find_string: str,
    replace_string: str,
    output_file: str,
    opt_case_insensitive: bool = False,
    runner: Runner | None = None,
) -> MetadataStringReplaceOutputs:
    """
    metadata-string-replace
    
    Replace a string in all metadata of a file.
    
    Replaces all occurrences of <find-string> in the metadata and map names of
    <input-file> with <replace-string>.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_file: the file to replace metadata in.
        find_string: the string to find.
        replace_string: the string to replace <find-string> with.
        output_file: output - the name to save the modified file as.
        opt_case_insensitive: match with case variation also.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetadataStringReplaceOutputs`).
    """
    params = metadata_string_replace_params(
        input_file=input_file,
        find_string=find_string,
        replace_string=replace_string,
        output_file=output_file,
        opt_case_insensitive=opt_case_insensitive,
    )
    return metadata_string_replace_execute(params, runner)


__all__ = [
    "METADATA_STRING_REPLACE_METADATA",
    "MetadataStringReplaceOutputs",
    "metadata_string_replace",
    "metadata_string_replace_execute",
    "metadata_string_replace_params",
]
